#!/bin/bash
# Exit immediately on error
set -eu -o pipefail

SOFTWARE=snpEff
VERSION=3.6
# Replace "." in official version number by "_" in archive version number
ARCHIVE=${SOFTWARE}_v${VERSION//./_}_core.zip
ARCHIVE_URL=http://sourceforge.net/projects/snpeff/files/$ARCHIVE
SOFTWARE_DIR=${SOFTWARE}_${VERSION//./_}

# Specific commands to extract and build the software
# $INSTALL_DIR and $INSTALL_DOWNLOAD have been set automatically
# $ARCHIVE has been downloaded in $INSTALL_DOWNLOAD
build() {
  cd $INSTALL_DOWNLOAD
  unzip $ARCHIVE

  # Install databases
  java -jar $SOFTWARE/snpEff.jar download GRCh37.75
  java -jar $SOFTWARE/snpEff.jar download GRCm38.75
  java -jar $SOFTWARE/snpEff.jar download hg19

  # Install software
  mv -i $SOFTWARE $INSTALL_DIR/$SOFTWARE_DIR
}

module_file() {
echo "\
#%Module1.0
proc ModulesHelp { } {
  puts stderr \"\tMUGQIC - $SOFTWARE \"
}
module-whatis \"$SOFTWARE\"

set             root                $INSTALL_DIR/$SOFTWARE_DIR
setenv          SNPEFF_HOME         \$root
"
}

# Call generic module install script once all variables and functions have been set
MODULE_INSTALL_SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
source $MODULE_INSTALL_SCRIPT_DIR/install_module.sh $@
